@@ -1,4 +1,3 @@
-#!/usr/bin/env bash
 if [[ ${1#lib} == $1 ]]
 	then LIBNAME=lib${1}
 	else LIBNAME=$1
@@ -6,7 +5,7 @@ fi
 TRLIBNAME=$(printf $LIBNAME | tr - _)
 cat > $1/src/Makefile.am <<EOF
 lib_LTLIBRARIES = ${LIBNAME}.la
-include_headers = lib.h g-hello-world.h
+include_HEADERS = lib.h g-hello-world.h
 
 ${TRLIBNAME}_la_SOURCES = g-hello-world.h g-hello-world-private.h g-hello-world.c g-hello-world.gob \\
 			  \$(BUILT_SOURCES)
